Documentation
¶
Index ¶
- type Belt
- type Class
- type Corpse
- type Data
- type Drop
- type Entrance
- type Entrances
- type HoverData
- type Inventory
- type Item
- func (i Item) Desc() item.Description
- func (i Item) FindStat(id stat.ID, layer int) (stat.Data, bool)
- func (i Item) GetSocketedItems() []Item
- func (i Item) HasPrefix(id int16) bool
- func (i Item) HasSocketedItems() bool
- func (i Item) HasSuffix(id int16) bool
- func (i Item) IsFromQuest() bool
- func (i Item) IsHealingPotion() bool
- func (i Item) IsManaPotion() bool
- func (i Item) IsPotion() bool
- func (i Item) IsRejuvPotion() bool
- func (i Item) Type() item.Type
- type ItemAffixes
- type KeyBinding
- type KeyBindings
- type Level
- type Monster
- func (m Monster) IsElite() bool
- func (m Monster) IsEscapingType() bool
- func (m Monster) IsGoodNPC() bool
- func (m Monster) IsImmune(resist stat.Resist) bool
- func (m Monster) IsMerc() bool
- func (m Monster) IsMonsterRaiser() bool
- func (m Monster) IsPet() bool
- func (m Monster) IsSealBoss() bool
- func (m Monster) IsSkip() bool
- type MonsterFilter
- type MonsterType
- type Monsters
- type NPC
- type NPCs
- type Object
- type Objects
- type OnlineGame
- type OpenMenus
- type Panel
- type PlayerUnit
- func (pu PlayerUnit) CastingFrames() int
- func (pu PlayerUnit) FindStat(id stat.ID, layer int) (stat.Data, bool)
- func (pu PlayerUnit) HPPercent() int
- func (pu PlayerUnit) HasDebuff() bool
- func (pu PlayerUnit) MPPercent() int
- func (pu PlayerUnit) MaxGold() int
- func (pu PlayerUnit) TotalPlayerGold() int
- type PointOfInterest
- type Position
- type PotionType
- type Room
- type Roster
- type RosterMember
- type SkillBinding
- type UnitID
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Belt ¶
func (Belt) GetFirstPotion ¶
func (b Belt) GetFirstPotion(potionType PotionType) (Position, bool)
type Corpse ¶
func (Corpse) StateNotInteractable ¶
type Data ¶
type Data struct {
AreaOrigin Position
Corpse Corpse
Monsters Monsters
Corpses Monsters
Game OnlineGame
PlayerUnit PlayerUnit
NPCs NPCs
Inventory Inventory
Objects Objects
Entrances Entrances
AdjacentLevels []Level
Rooms []Room
OpenMenus OpenMenus
Roster Roster
HoverData HoverData
TerrorZones []area.ID
Quests quest.Quests
KeyBindings KeyBindings
LegacyGraphics bool
IsIngame bool
HasMerc bool
ActiveWeaponSlot int
}
func (Data) MercHPPercent ¶
type Inventory ¶
func (Inventory) ByLocation ¶
func (i Inventory) ByLocation(locations ...item.LocationType) []Item
type Item ¶
type Item struct {
ID int
UnitID
Name item.Name
Quality item.Quality
IdentifiedName string
RunewordName item.RunewordName
LevelReq int
Position Position
Location item.Location
Ethereal bool
IsHovered bool
BaseStats stat.Stats
Stats stat.Stats
Affixes ItemAffixes
Sockets []Item
Identified bool
IsRuneword bool
IsNamed bool
IsStartItem bool
IsEar bool
IsBroken bool
HasBeenEquipped bool
HasSockets bool
InTradeOrStoreScreen bool
IsInSocket bool
UniqueSetID int32
}
func (Item) Desc ¶
func (i Item) Desc() item.Description
func (Item) GetSocketedItems ¶
func (Item) HasSocketedItems ¶
func (Item) IsFromQuest ¶
func (Item) IsHealingPotion ¶
func (Item) IsManaPotion ¶
func (Item) IsRejuvPotion ¶
type ItemAffixes ¶
type ItemAffixes struct {
Rare struct {
Prefix int16
Suffix int16
}
Magic struct {
Prefixes [3]int16 // Prefix1, Prefix2, Prefix3
Suffixes [3]int16 // Suffix1, Suffix2, Suffix3
}
}
func (ItemAffixes) GetMagicPrefixes ¶
func (a ItemAffixes) GetMagicPrefixes() []item.MagicPrefix
func (ItemAffixes) GetMagicSuffixes ¶
func (a ItemAffixes) GetMagicSuffixes() []item.MagicSuffix
func (ItemAffixes) GetRarePrefix ¶
func (a ItemAffixes) GetRarePrefix() (item.RarePrefix, bool)
func (ItemAffixes) GetRareSuffix ¶
func (a ItemAffixes) GetRareSuffix() (item.RareSuffix, bool)
type KeyBinding ¶
type KeyBindings ¶
type KeyBindings struct {
CharacterScreen KeyBinding
Inventory KeyBinding
HoradricCube KeyBinding
PartyScreen KeyBinding
MercenaryScreen KeyBinding
MessageLog KeyBinding
QuestLog KeyBinding
HelpScreen KeyBinding
SkillTree KeyBinding
SkillSpeedBar KeyBinding
Skills [16]SkillBinding
SelectPreviousSkill KeyBinding
SelectNextSkill KeyBinding
ShowBelt KeyBinding
UseBelt [4]KeyBinding
SwapWeapons KeyBinding
Chat KeyBinding
Run KeyBinding
ToggleRunWalk KeyBinding
StandStill KeyBinding
ForceMove KeyBinding
ShowItems KeyBinding
ShowPortraits KeyBinding
Automap KeyBinding
CenterAutomap KeyBinding
FadeAutomap KeyBinding
PartyOnAutomap KeyBinding
NamesOnAutomap KeyBinding
ToggleMiniMap KeyBinding
SayHelp KeyBinding
SayFollowMe KeyBinding
SayThisIsForYou KeyBinding
SayThanks KeyBinding
SaySorry KeyBinding
SayBye KeyBinding
SayNowYouDie KeyBinding
SayRetreat KeyBinding
ClearScreen KeyBinding
ClearMessages KeyBinding
Zoom KeyBinding
LegacyToggle KeyBinding
}
func (KeyBindings) KeyBindingForSkill ¶
func (kb KeyBindings) KeyBindingForSkill(skillID skill.ID) (KeyBinding, bool)
func (KeyBindings) MustKBForSkill ¶
func (kb KeyBindings) MustKBForSkill(skillID skill.ID) KeyBinding
type Monster ¶
type Monster struct {
UnitID
Name npc.ID
IsHovered bool
Position Position
Stats map[stat.ID]int
Type MonsterType
States state.States
Mode mode.NpcMode
}
func (Monster) IsEscapingType ¶
IsEscapingType Monster cannot be attacked when airborne or hide in water (NpcMode 8)
func (Monster) IsMonsterRaiser ¶
IsMonsterRaiser returns true if the monster is able to spawn new monsters.
func (Monster) IsSealBoss ¶
type MonsterFilter ¶
func MonsterAnyFilter ¶
func MonsterAnyFilter() MonsterFilter
func MonsterEliteFilter ¶
func MonsterEliteFilter() MonsterFilter
type MonsterType ¶
type MonsterType string
const ( // Monster Types MonsterTypeNone MonsterType = "None" MonsterTypeChampion MonsterType = "Champion" MonsterTypeMinion MonsterType = "Minion" MonsterTypeUnique MonsterType = "Unique" MonsterTypeSuperUnique MonsterType = "SuperUnique" )
type Monsters ¶
type Monsters []Monster
func (Monsters) Enemies ¶
func (m Monsters) Enemies(filters ...MonsterFilter) []Monster
type Object ¶
type Object struct {
ID UnitID
object.Name
IsHovered bool
Selectable bool
InteractType object.InteractType
Shrine object.ShrineData
Position Position
Owner string
Mode mode.ObjectMode
PortalData object.PortalData
}
func (Object) IsRedPortal ¶
func (Object) IsSuperChest ¶
func (Object) IsWaypoint ¶
type OnlineGame ¶
type OpenMenus ¶
type OpenMenus struct {
Inventory bool
LoadingScreen bool
NPCInteract bool
NPCShop bool
Stash bool
Waypoint bool
MapShown bool
NewSkills bool
NewStats bool
SkillTree bool
Character bool
QuitMenu bool
Cube bool
SkillSelect bool
Anvil bool
MercInventory bool
BeltRows bool
QuestLog bool
PortraitsShown bool
ChatOpen bool
}
func (OpenMenus) IsMenuOpen ¶
type PlayerUnit ¶
type PlayerUnit struct {
Address uintptr
Name string
ID UnitID
Area area.ID
Position Position
Stats stat.Stats
BaseStats stat.Stats
Skills map[skill.ID]skill.Points
States state.States
Class Class
LeftSkill skill.ID
RightSkill skill.ID
AvailableWaypoints []area.ID // Is only filled when WP menu is open and only for the specific selected tab
Mode mode.PlayerMode
}
func (PlayerUnit) CastingFrames ¶
func (pu PlayerUnit) CastingFrames() int
func (PlayerUnit) HPPercent ¶
func (pu PlayerUnit) HPPercent() int
func (PlayerUnit) HasDebuff ¶
func (pu PlayerUnit) HasDebuff() bool
func (PlayerUnit) MPPercent ¶
func (pu PlayerUnit) MPPercent() int
func (PlayerUnit) MaxGold ¶
func (pu PlayerUnit) MaxGold() int
func (PlayerUnit) TotalPlayerGold ¶
func (pu PlayerUnit) TotalPlayerGold() int
TotalPlayerGold returns the amount of gold, including inventory and player stash (excluding shared stash)
type PointOfInterest ¶
type PotionType ¶
type PotionType string
const ( HealingPotion PotionType = "HealingPotion" ManaPotion PotionType = "ManaPotion" RejuvenationPotion PotionType = "RejuvenationPotion" )
type Roster ¶
type Roster []RosterMember
func (Roster) FindByName ¶
func (r Roster) FindByName(name string) (RosterMember, bool)
type SkillBinding ¶
type SkillBinding struct {
SkillID skill.ID
KeyBinding
}
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Code generated by cmd/txttocode.
|
Code generated by cmd/txttocode. |
|
Code generated by cmd/txttocode.
|
Code generated by cmd/txttocode. |
|
Code generated by cmd/txttocode.
|
Code generated by cmd/txttocode. |
|
Code generated by cmd/txttocode.
|
Code generated by cmd/txttocode. |
|
Code generated by cmd/txttocode.
|
Code generated by cmd/txttocode. |
Click to show internal directories.
Click to hide internal directories.